@@ -1,4 +1,4 @@
-// $Id: parser.c,v 1.11 2002/08/27 17:19:45 ensc Exp $    --*- c++ -*--
+// $Id: parser.c,v 1.17 2003/07/03 13:32:52 ensc Exp $    --*- c++ -*--
 
 // Copyright (C) 2002 Enrico Scholz <enrico.scholz@informatik.tu-chemnitz.de>
 //  
@@ -83,7 +83,7 @@ initCharacterClassification(/*@out@*/unsigned int *chrs)
   
   chrs['\t'] |= chrBLANK;
   chrs[' ']  |= chrBLANK;
-  chrs['.']  |= chrIP | chrFILENAME | chrUSERNAME;
+  chrs['.']  |= chrSYS | chrUSERNAME | chrIP;
   chrs['_']  |= chrSYS | chrUSERNAME;
   chrs['-']  |= chrSYS | chrUSERNAME;
   chrs[':']  |= chrSYS;
@@ -210,8 +210,9 @@ newInterface(struct InterfaceInfoList *ifs)
   assert(ifs->dta!=0);
   
   result        = &ifs->dta[ifs->len - 1];
+  memset(result, 0, sizeof result);
   result->if_ip = INADDR_NONE;
-
+  
   return result;
 }
 
@@ -220,14 +221,18 @@ newServer(struct ServerInfoList *servers)
     /*@modifies *servers@*/
 {
   size_t		new_len;
+  struct ServerInfo	*result;
   
   ++servers->len;
   new_len      = servers->len * (sizeof(*servers->dta));
   servers->dta = static_cast(struct ServerInfo *)(Erealloc(servers->dta, new_len));
 
   assert(servers->dta!=0);
+  result	 = &servers->dta[servers->len - 1];
+  result->type   = svUNICAST;
+  memset(&result->info, 0, sizeof result->info);
   
-  return &servers->dta[servers->len - 1];
+  return result;
 }
 
 inline static /*@exposed@*/ struct UlimitInfo *
